@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.18-371.4.AXS3.src.rpm ]
+if [ ! -r kernel-2.6.18-398.1.AXS3.src.rpm ]
 then
-    wget http://ftp.miraclelinux.com/pub/Asianux/Server/3.0/updates/src/kernel-2.6.18-371.4.AXS3.src.rpm || die "Can't download source package."
+    wget http://ftp.miraclelinux.com/pub/Asianux/Server/3.0/updates/src/kernel-2.6.18-398.1.AXS3.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.18-371.4.AXS3.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.18-371.4.AXS3.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.18-398.1.AXS3.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.18-398.1.AXS3.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.9-20140915.tar.gz ]
+if [ ! -r ccs-patch-1.6.9-20161111.tar.gz ]
 then
-    wget -O ccs-patch-1.6.9-20140915.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20140915.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.6.9-20161111.tar.gz 'http://osdn.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20161111.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -32,8 +32,8 @@ patch << "EOF" || die "Can't patch spec file."
  %define kversion 2.6.%{sublevel}.%{stablerev}
  %define rpmversion 2.6.%{sublevel}
  # %dist is defined in Asianux VPBS
--%define release %{revision}.4%{dist}
-+%define release %{revision}.4%{dist}_tomoyo_1.6.9p4
+-%define release %{revision}.1%{dist}
++%define release %{revision}.1%{dist}_tomoyo_1.6.9p4
  %define signmodules 0
  %define xen_hv_cset 15502
  %define xen_abi_ver 3.1
@@ -56,24 +56,23 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -1048,6 +1051,10 @@
+@@ -1042,6 +1045,10 @@
  %patch200100 -p1
  # end of Asianux patches
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.9-20140915.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.9-20161111.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.18-asianux-3.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -1099,6 +1106,9 @@
+@@ -1093,6 +1100,8 @@
  for i in `ls *86*.config`
  do
    mv $i .config
 +  # TOMOYO Linux
 +  cat config.ccs >> .config
-+  sed -i -e "s/^CONFIG_DEBUG_INFO=.*/# CONFIG_DEBUG_INFO is not set/" -- .config 
    Arch=`head -1 .config | cut -b 3-`
    make ARCH=$Arch nonint_oldconfig > /dev/null
    echo "# $Arch" > configs/$i
